@@ -1,5 +1,5 @@
 ﻿/**
- * @license Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
+ * @license Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
  * For licensing, see LICENSE.md or https://ckeditor.com/license
  */
 
@@ -13,10 +13,10 @@
  * (1) https://ckeditor.com/cke4/builder
  *     Visit online builder to build CKEditor from scratch.
  *
- * (2) https://ckeditor.com/cke4/builder/1bc547fc070f76f9fb607dd68afe68a7
+ * (2) https://ckeditor.com/cke4/builder/60ddbd6ef3e73f77d004b7220cff69dc
  *     Visit online builder to build CKEditor, starting with the same setup as before.
  *
- * (3) https://ckeditor.com/cke4/builder/download/1bc547fc070f76f9fb607dd68afe68a7
+ * (3) https://ckeditor.com/cke4/builder/download/60ddbd6ef3e73f77d004b7220cff69dc
  *     Straight download link to the latest version of CKEditor (Optimized) with the same setup as before.
  *
  * NOTE:
@@ -39,7 +39,6 @@ var CKBUILDER_CONFIG = {
 		'.jshintrc',
 		'.mailmap',
 		'.npm',
-		'.nvmrc',
 		'.travis.yml',
 		'bender-err.log',
 		'bender-out.log',
@@ -49,7 +48,6 @@ var CKBUILDER_CONFIG = {
 		'gruntfile.js',
 		'less',
 		'node_modules',
-		'package-lock.json',
 		'package.json',
 		'tests'
 	],
@@ -58,6 +56,7 @@ var CKBUILDER_CONFIG = {
 		'about' : 1,
 		'basicstyles' : 1,
 		'blockquote' : 1,
+		'ccmsconfighelper' : 1,
 		'clipboard' : 1,
 		'colorbutton' : 1,
 		'confighelper' : 1,
@@ -87,8 +86,7 @@ var CKBUILDER_CONFIG = {
 		'table' : 1,
 		'toolbar' : 1,
 		'undo' : 1,
-		'uploadimage' : 1,
-		'wysiwygarea' : 1
+		'uploadimage' : 1
 	},
 	languages : {
 		'af' : 1,
