@@ -1,6 +1,6 @@
 /**
- * @license Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
- * For licensing, see LICENSE.md or http://ckeditor.com/license
+ * @license Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
+ * For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
  */
 
 /**
@@ -83,11 +83,58 @@ CKEDITOR.NODE_COMMENT = 8;
  */
 CKEDITOR.NODE_DOCUMENT_FRAGMENT = 11;
 
+/**
+ * Indicates that positions of both nodes are identical (this is the same node). See {@link CKEDITOR.dom.node#getPosition}.
+ *
+ * @readonly
+ * @property {Number} [=0]
+ * @member CKEDITOR
+ */
 CKEDITOR.POSITION_IDENTICAL = 0;
+
+/**
+ * Indicates that nodes are in different (detached) trees. See {@link CKEDITOR.dom.node#getPosition}.
+ *
+ * @readonly
+ * @property {Number} [=1]
+ * @member CKEDITOR
+ */
 CKEDITOR.POSITION_DISCONNECTED = 1;
+
+/**
+ * Indicates that the context node follows the other node. See {@link CKEDITOR.dom.node#getPosition}.
+ *
+ * @readonly
+ * @property {Number} [=2]
+ * @member CKEDITOR
+ */
 CKEDITOR.POSITION_FOLLOWING = 2;
+
+/**
+ * Indicates that the context node precedes the other node. See {@link CKEDITOR.dom.node#getPosition}.
+ *
+ * @readonly
+ * @property {Number} [=4]
+ * @member CKEDITOR
+ */
 CKEDITOR.POSITION_PRECEDING = 4;
+
+/**
+ * Indicates that the context node is a descendant of the other node. See {@link CKEDITOR.dom.node#getPosition}.
+ *
+ * @readonly
+ * @property {Number} [=8]
+ * @member CKEDITOR
+ */
 CKEDITOR.POSITION_IS_CONTAINED = 8;
+
+/**
+ * Indicates that the context node contains the other node. See {@link CKEDITOR.dom.node#getPosition}.
+ *
+ * @readonly
+ * @property {Number} [=16]
+ * @member CKEDITOR
+ */
 CKEDITOR.POSITION_CONTAINS = 16;
 
 CKEDITOR.tools.extend( CKEDITOR.dom.node.prototype, {
@@ -153,7 +200,7 @@ CKEDITOR.tools.extend( CKEDITOR.dom.node.prototype, {
 		}
 
 		// IE8 rename HTML5 nodes by adding `:` at the begging of the tag name when the node is cloned,
-		// so `<figure>` will be `<:figure>` after 'cloneNode'. We need to fix it (#13101).
+		// so `<figure>` will be `<:figure>` after 'cloneNode'. We need to fix it (https://dev.ckeditor.com/ticket/13101).
 		function renameNodes( node ) {
 			if ( node.type != CKEDITOR.NODE_ELEMENT && node.type != CKEDITOR.NODE_DOCUMENT_FRAGMENT )
 				return;
@@ -262,15 +309,15 @@ CKEDITOR.tools.extend( CKEDITOR.dom.node.prototype, {
 	getAddress: function( normalized ) {
 		var address = [];
 		var $documentElement = this.getDocument().$.documentElement;
-		var node = this.$;
+		var node = this;
 
 		while ( node && node != $documentElement ) {
-			var parentNode = node.parentNode;
+			var parentNode = node.getParent();
 
 			if ( parentNode ) {
 				// Get the node index. For performance, call getIndex
 				// directly, instead of creating a new node object.
-				address.unshift( this.getIndex.call( { $: node }, normalized ) );
+				address.unshift( this.getIndex.call( node, normalized ) );
 			}
 
 			node = parentNode;
@@ -316,17 +363,17 @@ CKEDITOR.tools.extend( CKEDITOR.dom.node.prototype, {
 		// Attention: getAddress depends on this.$
 		// getIndex is called on a plain object: { $ : node }
 
-		var current = this.$,
+		var current = this,
 			index = -1,
 			isNormalizing;
 
-		if ( !this.$.parentNode )
+		if ( !this.getParent() )
 			return -1;
 
 		// The idea is - all empty text nodes will be virtually merged into their adjacent text nodes.
 		// If an empty text node does not have an adjacent non-empty text node we can return -1 straight away,
 		// because it and all its sibling text nodes will be merged into an empty text node and then totally ignored.
-		if ( normalized && current.nodeType == CKEDITOR.NODE_TEXT && !current.nodeValue ) {
+		if ( normalized && current.type == CKEDITOR.NODE_TEXT && current.isEmpty() ) {
 			var adjacent = getAdjacentNonEmptyTextNode( current ) || getAdjacentNonEmptyTextNode( current, true );
 
 			if ( !adjacent )
@@ -335,26 +382,27 @@ CKEDITOR.tools.extend( CKEDITOR.dom.node.prototype, {
 
 		do {
 			// Bypass blank node and adjacent text nodes.
-			if ( normalized && current != this.$ && current.nodeType == CKEDITOR.NODE_TEXT && ( isNormalizing || !current.nodeValue ) )
+			if ( normalized && !current.equals( this ) && current.type == CKEDITOR.NODE_TEXT && ( isNormalizing || current.isEmpty() ) ) {
 				continue;
+			}
 
 			index++;
-			isNormalizing = current.nodeType == CKEDITOR.NODE_TEXT;
+			isNormalizing = current.type == CKEDITOR.NODE_TEXT;
 		}
-		while ( ( current = current.previousSibling ) );
+		while ( ( current = current.getPrevious() ) );
 
 		return index;
 
 		function getAdjacentNonEmptyTextNode( node, lookForward ) {
-			var sibling = lookForward ? node.nextSibling : node.previousSibling;
+			var sibling = lookForward ? node.getNext() : node.getPrevious();
 
-			if ( !sibling || sibling.nodeType != CKEDITOR.NODE_TEXT ) {
+			if ( !sibling || sibling.type != CKEDITOR.NODE_TEXT ) {
 				return null;
 			}
 
 			// If found a non-empty text node, then return it.
 			// If not, then continue search.
-			return sibling.nodeValue ? sibling : getAdjacentNonEmptyTextNode( sibling, lookForward );
+			return sibling.isEmpty() ? getAdjacentNonEmptyTextNode( sibling, lookForward ) : sibling;
 		}
 	},
 
@@ -551,10 +599,10 @@ CKEDITOR.tools.extend( CKEDITOR.dom.node.prototype, {
 
 	/**
 	 * Determines the position relation between this node and the given {@link CKEDITOR.dom.node} in the document.
-	 * This node can be preceding ({@link CKEDITOR.POSITION_PRECEDING}) or following ({@link CKEDITOR.POSITION_FOLLOWING})
-	 * the given node. This node can also contain ({@link CKEDITOR.POSITION_CONTAINS}) or be contained by
-	 * ({@link CKEDITOR.POSITION_IS_CONTAINED}) the given node. The function returns a bitmask of constants
-	 * listed above or {@link CKEDITOR.POSITION_IDENTICAL} if the given node is the same as this node.
+	 * This node can be preceding ({@link CKEDITOR#POSITION_PRECEDING}) or following ({@link CKEDITOR#POSITION_FOLLOWING})
+	 * the given node. This node can also contain ({@link CKEDITOR#POSITION_CONTAINS}) or be contained by
+	 * ({@link CKEDITOR#POSITION_IS_CONTAINED}) the given node. The function returns a bitmask of constants
+	 * listed above or {@link CKEDITOR#POSITION_IDENTICAL} if the given node is the same as this node.
 	 *
 	 * @param {CKEDITOR.dom.node} otherNode A node to check relation with.
 	 * @returns {Number} Position relation between this node and given node.
@@ -752,7 +800,7 @@ CKEDITOR.tools.extend( CKEDITOR.dom.node.prototype, {
 				} else if ( trimmed.length < originalLength ) {
 					child.split( originalLength - trimmed.length );
 
-					// IE BUG: child.remove() may raise JavaScript errors here. (#81)
+					// IE BUG: child.remove() may raise JavaScript errors here. (https://dev.ckeditor.com/ticket/81)
 					this.$.removeChild( this.$.firstChild );
 				}
 			}
@@ -777,7 +825,7 @@ CKEDITOR.tools.extend( CKEDITOR.dom.node.prototype, {
 					child.split( trimmed.length );
 
 					// IE BUG: child.getNext().remove() may raise JavaScript errors here.
-					// (#81)
+					// (https://dev.ckeditor.com/ticket/81)
 					this.$.lastChild.parentNode.removeChild( this.$.lastChild );
 				}
 			}
@@ -788,7 +836,7 @@ CKEDITOR.tools.extend( CKEDITOR.dom.node.prototype, {
 			child = this.$.lastChild;
 
 			if ( child && child.type == 1 && child.nodeName.toLowerCase() == 'br' ) {
-				// Use "eChildNode.parentNode" instead of "node" to avoid IE bug (#324).
+				// Use "eChildNode.parentNode" instead of "node" to avoid IE bug (https://dev.ckeditor.com/ticket/324).
 				child.parentNode.removeChild( child );
 			}
 		}
@@ -812,9 +860,9 @@ CKEDITOR.tools.extend( CKEDITOR.dom.node.prototype, {
 	 * you can temporarily attach this tree to an element with the `data-cke-editable` attribute and use the
 	 * `checkOnlyAttributes` mode.
 	 *
-	 * @since 3.5
+	 * @since 3.5.0
 	 * @param {Boolean} [checkOnlyAttributes=false] If `true`, only attributes will be checked, native methods will not
-	 * be used. This parameter needs to be `true` to check hidden or detached elements. Introduced in 4.5.
+	 * be used. This parameter needs to be `true` to check hidden or detached elements. Introduced in 4.5.0.
 	 * @returns {Boolean}
 	 */
 	isReadOnly: function( checkOnlyAttributes ) {
@@ -822,8 +870,8 @@ CKEDITOR.tools.extend( CKEDITOR.dom.node.prototype, {
 		if ( this.type != CKEDITOR.NODE_ELEMENT )
 			element = this.getParent();
 
-		// Prevent Edge crash. #13609.
-		if ( CKEDITOR.env.edge && element && element.is( 'textarea' ) ) {
+		// Prevent Edge crash (https://dev.ckeditor.com/ticket/13609, https://dev.ckeditor.com/ticket/13919).
+		if ( CKEDITOR.env.edge && element && element.is( 'textarea', 'input' ) ) {
 			checkOnlyAttributes = true;
 		}
 
