@@ -1,6 +1,6 @@
 ﻿/*
-Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
-For licensing, see LICENSE.md or http://ckeditor.com/license
+Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
+For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */
 CKEDITOR.plugins.setLang( 'colorbutton', 'nb', {
 	auto: 'Automatisk',
@@ -11,7 +11,7 @@ CKEDITOR.plugins.setLang( 'colorbutton', 'nb', {
 		'8B4513': 'Salbrun',
 		'2F4F4F': 'Grønnsvart',
 		'008080': 'Blågrønn',
-		'000080': 'Marineblått',
+		'000080': 'Marineblå',
 		'4B0082': 'Indigo',
 		'696969': 'Mørk grå',
 		B22222: 'Mørkerød',
@@ -35,17 +35,39 @@ CKEDITOR.plugins.setLang( 'colorbutton', 'nb', {
 		FFFF00: 'Gul',
 		'00FF00': 'Lime',
 		AFEEEE: 'Svak turkis',
-		ADD8E6: 'Lys Blå',
+		ADD8E6: 'Lys blå',
 		DDA0DD: 'Plomme',
 		D3D3D3: 'Lys grå',
 		FFF0F5: 'Svak lavendelrosa',
 		FAEBD7: 'Antikk-hvit',
 		FFFFE0: 'Lys gul',
 		F0FFF0: 'Honningmelon',
-		F0FFFF: 'Svakt asurblått',
+		F0FFFF: 'Svak asurblå',
 		F0F8FF: 'Svak cyan',
 		E6E6FA: 'Lavendel',
-		FFF: 'Hvit'
+		FFF: 'Hvit',
+		'1ABC9C': 'Sterk cyan',
+		'2ECC71': 'Smaragd',
+		'3498DB': 'Lys blå',
+		'9B59B6': 'Ametyst',
+		'4E5F70': 'Gråaktig blå',
+		'F1C40F': 'Livaktig gul',
+		'16A085': 'Mørk cyan',
+		'27AE60': 'Mørk smaragd',
+		'2980B9': 'Sterk blå',
+		'8E44AD': 'Mørk fiolett',
+		'2C3E50': 'Desaturert blå',
+		'F39C12': 'Oransje',
+		'E67E22': 'Gulrot',
+		'E74C3C': 'Blek rød',
+		'ECF0F1': 'Klar sølv',
+		'95A5A6': 'Lys gråaktig cyan',
+		'DDD': 'Lys grå',
+		'D35400': 'Gresskar',
+		'C0392B': 'Sterk rød',
+		'BDC3C7': 'Sølv',
+		'7F8C8D': 'Gråaktig cyan',
+		'999': 'Mørk grå'
 	},
 	more: 'Flere farger...',
 	panelTitle: 'Farger',
