@@ -1,6 +1,6 @@
-﻿/**
- * @license Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
- * For licensing, see LICENSE.md or http://ckeditor.com/license
+/**
+ * @license Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
+ * For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
  */
 
 ( function() {
@@ -30,7 +30,11 @@
 	} );
 
 	var whitespaces = CKEDITOR.dom.walker.whitespaces(),
-		bookmark = CKEDITOR.dom.walker.bookmark();
+		bookmark = CKEDITOR.dom.walker.bookmark(),
+		plugin,
+		enterBr,
+		enterBlock,
+		headerTagRegex;
 
 	CKEDITOR.plugins.enterkey = {
 		enterBlock: function( editor, mode, range, forceMode ) {
@@ -43,7 +47,7 @@
 				return;
 
 			// When range is in nested editable, we have to replace range with this one,
-			// which have root property set to closest editable, to make auto paragraphing work. (#12162)
+			// which have root property set to closest editable, to make auto paragraphing work. (https://dev.ckeditor.com/ticket/12162)
 			range = replaceRangeWithClosestEditableRoot( range );
 
 			var doc = range.document;
@@ -58,16 +62,32 @@
 
 				newBlock;
 
-			// Exit the list when we're inside an empty list item block. (#5376)
-			if ( atBlockStart && atBlockEnd ) {
-				// Exit the list when we're inside an empty list item block. (#5376)
-				if ( block && ( block.is( 'li' ) || block.getParent().is( 'li' ) ) ) {
-					// Make sure to point to the li when dealing with empty list item.
-					if ( !block.is( 'li' ) )
-						block = block.getParent();
+			if ( block && atBlockStart && atBlockEnd ) {
+				var blockParent = block.getParent();
 
-					var blockParent = block.getParent(),
-						blockGrandParent = blockParent.getParent(),
+				// Block placeholder breaks list structure (#2205).
+				if ( blockParent.is( 'li' ) && blockParent.getChildCount() > 1 ) {
+					var placeholder = new CKEDITOR.dom.element( 'li' ),
+						newRange = editor.createRange();
+
+					placeholder.insertAfter( blockParent );
+
+					block.remove();
+
+					newRange.setStart( placeholder, 0 );
+					editor.getSelection().selectRanges( [ newRange ] );
+
+					return;
+				}
+				// Exit the list when we're inside an empty list item block. (https://dev.ckeditor.com/ticket/5376).
+				else if ( block.is( 'li' ) || block.getParent().is( 'li' ) ) {
+					// Make sure to point to the li when dealing with empty list item.
+					if ( !block.is( 'li' ) ) {
+						block = block.getParent();
+						blockParent = block.getParent();
+					}
+
+					var blockGrandParent = blockParent.getParent(),
 
 						firstChild = !block.hasPrevious(),
 						lastChild = !block.hasNext(),
@@ -293,7 +313,7 @@
 
 			var node;
 
-			// If this is a block under a list item, split it as well. (#1647)
+			// If this is a block under a list item, split it as well. (https://dev.ckeditor.com/ticket/1647)
 			if ( nextBlock ) {
 				node = nextBlock.getParent();
 				if ( node.is( 'li' ) ) {
@@ -306,14 +326,13 @@
 				range.moveToElementEditStart( node );
 				previousBlock.move( previousBlock.getPrevious() );
 			}
-
 			// If we have both the previous and next blocks, it means that the
 			// boundaries were on separated blocks, or none of them where on the
 			// block limits (start/end).
 			if ( !isStartOfBlock && !isEndOfBlock ) {
 				// If the next block is an <li> with another list tree as the first
 				// child, we'll need to append a filler (<br>/NBSP) or the list item
-				// wouldn't be editable. (#1420)
+				// wouldn't be editable. (https://dev.ckeditor.com/ticket/1420)
 				if ( nextBlock.is( 'li' ) ) {
 					var walkerRange = range.clone();
 					walkerRange.selectNodeContents( nextBlock );
@@ -330,12 +349,18 @@
 				// Move the selection to the end block.
 				if ( nextBlock )
 					range.moveToElementEditStart( nextBlock );
+			}
+			// Handle differently when content of table cell was erased by pressing enter (#1816).
+			// We don't want to add new block, because it was created with range.splitBlock().
+			else if ( preventExtraLineInsideTable( mode ) ) {
+				range.moveToElementEditStart( range.getTouchedStartNode() );
 			} else {
+
 				var newBlockDir;
 
 				if ( previousBlock ) {
 					// Do not enter this block if it's a header tag, or we are in
-					// a Shift+Enter (#77). Create a new block element instead
+					// a Shift+Enter (https://dev.ckeditor.com/ticket/77). Create a new block element instead
 					// (later in the code).
 					if ( previousBlock.is( 'li' ) || !( headerTagRegex.test( previousBlock.getName() ) || previousBlock.is( 'pre' ) ) ) {
 						// Otherwise, duplicate the previous block.
@@ -346,7 +371,7 @@
 				}
 
 				if ( !newBlock ) {
-					// We have already created a new list item. (#6849)
+					// We have already created a new list item. (https://dev.ckeditor.com/ticket/6849)
 					if ( node && node.is( 'li' ) )
 						newBlock = node;
 					else {
@@ -384,8 +409,8 @@
 				if ( !newBlock.getParent() )
 					range.insertNode( newBlock );
 
-				// list item start number should not be duplicated (#7330), but we need
-				// to remove the attribute after it's onto the DOM tree because of old IEs (#7581).
+				// list item start number should not be duplicated (https://dev.ckeditor.com/ticket/7330), but we need
+				// to remove the attribute after it's onto the DOM tree because of old IEs (https://dev.ckeditor.com/ticket/7581).
 				newBlock.is( 'li' ) && newBlock.removeAttribute( 'value' );
 
 				// This is tricky, but to make the new block visible correctly
@@ -405,6 +430,42 @@
 
 			range.select();
 			range.scrollIntoView();
+
+			// ===== HELPERS =====
+			function preventExtraLineInsideTable( mode ) {
+				// #1816
+				// We want to have behaviour after pressing enter like this:
+				// 1. <td>^</td> -> <td><p> </p></td>
+				// 2. <td>Foo^</td> -> <td><p>Foo</p><p> </p></td>
+				// 3. <td>Foo^Bar</td> -> <td><p>Foo</p><p>Bar</p></td>
+				// We need to separate 1. case to not add extra line. Like it happen for 2nd or 3rd option.
+
+				var innerElement,
+					bogus;
+
+				if ( mode === CKEDITOR.ENTER_BR ) {
+					return false;
+				}
+
+				if ( CKEDITOR.tools.indexOf( [ 'td', 'th' ], path.lastElement.getName() ) === -1 ) {
+					return false;
+				}
+				if ( path.lastElement.getChildCount() !== 1 ) {
+					return false;
+				}
+
+				innerElement = path.lastElement.getChild( 0 ).clone( true );
+				bogus = innerElement.getBogus();
+				if ( bogus ) {
+					bogus.remove();
+				}
+
+				if ( innerElement.getText().length ) {
+					return false;
+				}
+
+				return true;
+			}
 		},
 
 		enterBr: function( editor, mode, range, forceMode ) {
@@ -453,7 +514,7 @@
 			} else {
 				var lineBreak;
 
-				// IE<8 prefers text node as line-break inside of <pre> (#4711).
+				// IE<8 prefers text node as line-break inside of <pre> (https://dev.ckeditor.com/ticket/4711).
 				if ( startBlockTag == 'pre' && CKEDITOR.env.ie && CKEDITOR.env.version < 8 )
 					lineBreak = doc.createText( '\r' );
 				else
@@ -495,15 +556,15 @@
 		}
 	};
 
-	var plugin = CKEDITOR.plugins.enterkey,
-		enterBr = plugin.enterBr,
-		enterBlock = plugin.enterBlock,
-		headerTagRegex = /^h[1-6]$/;
+	plugin = CKEDITOR.plugins.enterkey;
+	enterBr = plugin.enterBr;
+	enterBlock = plugin.enterBlock;
+	headerTagRegex = /^h[1-6]$/;
 
 	function shiftEnter( editor ) {
 		// On SHIFT+ENTER:
 		// 1. We want to enforce the mode to be respected, instead
-		// of cloning the current block. (#77)
+		// of cloning the current block. (https://dev.ckeditor.com/ticket/77)
 		return enter( editor, editor.activeShiftEnterMode, 1 );
 	}
 
@@ -521,7 +582,8 @@
 		// Check path block specialities:
 		// 1. Cannot be a un-splittable element, e.g. table caption;
 		var path = editor.elementPath();
-		if ( !path.isContextFor( 'p' ) ) {
+
+		if ( path && !path.isContextFor( 'p' ) ) {
 			mode = CKEDITOR.ENTER_BR;
 			forceMode = 1;
 		}
