@@ -1,6 +1,6 @@
 /**
- * @license Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
- * For licensing, see LICENSE.md or http://ckeditor.com/license
+ * @license Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
+ * For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
  */
 
 CKEDITOR.plugins.add( 'floatpanel', {
@@ -31,7 +31,7 @@ CKEDITOR.plugins.add( 'floatpanel', {
 	/**
 	 * Represents a floating panel UI element.
 	 *
-	 * It's reused by rich combos, color combos, menus, etc.
+	 * It is reused by rich combos, color combos, menus, etc.
 	 * and it renders its content using {@link CKEDITOR.ui.panel}.
 	 *
 	 * @class
@@ -61,7 +61,7 @@ CKEDITOR.plugins.add( 'floatpanel', {
 				iframe = element.getFirst(),
 				that = this;
 
-			// Disable native browser menu. (#4825)
+			// Disable native browser menu. (https://dev.ckeditor.com/ticket/4825)
 			element.disableContextMenu();
 
 			this.element = element;
@@ -75,17 +75,19 @@ CKEDITOR.plugins.add( 'floatpanel', {
 				document: doc,
 				iframe: iframe,
 				children: [],
-				dir: editor.lang.dir
+				dir: editor.lang.dir,
+				showBlockParams: null,
+				markFirst: definition.markFirst !== undefined ? definition.markFirst : true
 			};
 
 			editor.on( 'mode', hide );
 			editor.on( 'resize', hide );
 
-			// Window resize doesn't cause hide on blur. (#9800)
-			// [iOS] Poping up keyboard triggers window resize
-			// which leads to undesired panel hides.
-			if ( !CKEDITOR.env.iOS )
-				doc.getWindow().on( 'resize', hide );
+			// When resize of the window is triggered floatpanel should be repositioned according to new dimensions.
+			// https://dev.ckeditor.com/ticket/11724. Fixes issue with undesired panel hiding on Android and iOS.
+			doc.getWindow().on( 'resize', function() {
+				this.reposition();
+			}, this );
 
 			// We need a wrapper because events implementation doesn't allow to attach
 			// one listener more than once for the same event on the same object.
@@ -118,7 +120,7 @@ CKEDITOR.plugins.add( 'floatpanel', {
 			},
 
 			/**
-			 * Shows panel block.
+			 * Shows the panel block.
 			 *
 			 * @param {String} name
 			 * @param {CKEDITOR.dom.element} offsetParent Positioned parent.
@@ -144,6 +146,7 @@ CKEDITOR.plugins.add( 'floatpanel', {
 				var panel = this._.panel,
 					block = panel.showBlock( name );
 
+				this._.showBlockParams = [].slice.call( arguments );
 				this.allowBlur( false );
 
 				// Record from where the focus is when open panel.
@@ -153,7 +156,7 @@ CKEDITOR.plugins.add( 'floatpanel', {
 
 				var element = this.element,
 					iframe = this._.iframe,
-					// Edge prefers iframe's window to the iframe, just like the rest of the browsers (#13143).
+					// Edge prefers iframe's window to the iframe, just like the rest of the browsers (https://dev.ckeditor.com/ticket/13143).
 					focused = CKEDITOR.env.ie && !CKEDITOR.env.edge ? iframe : new CKEDITOR.dom.window( iframe.$.contentWindow ),
 					doc = element.getDocument(),
 					positionedAncestor = this._.parentElement.getPositionedAncestor(),
@@ -163,7 +166,7 @@ CKEDITOR.plugins.add( 'floatpanel', {
 					left = position.x + ( offsetX || 0 ) - positionedAncestorPosition.x,
 					top = position.y + ( offsetY || 0 ) - positionedAncestorPosition.y;
 
-				// Floating panels are off by (-1px, 0px) in RTL mode. (#3438)
+				// Floating panels are off by (-1px, 0px) in RTL mode. (https://dev.ckeditor.com/ticket/3438)
 				if ( rtl && ( corner == 1 || corner == 4 ) )
 					left += offsetParent.$.offsetWidth;
 				else if ( !rtl && ( corner == 2 || corner == 3 ) )
@@ -196,7 +199,7 @@ CKEDITOR.plugins.add( 'floatpanel', {
 
 					// With addEventListener compatible browsers, we must
 					// useCapture when registering the focus/blur events to
-					// guarantee they will be firing in all situations. (#3068, #3222 )
+					// guarantee they will be firing in all situations. (https://dev.ckeditor.com/ticket/3068, https://dev.ckeditor.com/ticket/3222 )
 					CKEDITOR.event.useCapture = true;
 
 					focused.on( 'blur', function( ev ) {
@@ -209,7 +212,7 @@ CKEDITOR.plugins.add( 'floatpanel', {
 
 						if ( this.visible && !this._.activeChild ) {
 							// [iOS] Allow hide to be prevented if touch is bound
-							// to any parent of the iframe blur happens before touch (#10714).
+							// to any parent of the iframe blur happens before touch (https://dev.ckeditor.com/ticket/10714).
 							if ( CKEDITOR.env.iOS ) {
 								if ( !this._.hideTimeout )
 									this._.hideTimeout = CKEDITOR.tools.setTimeout( doHide, 0, this );
@@ -233,7 +236,7 @@ CKEDITOR.plugins.add( 'floatpanel', {
 					}, this );
 
 					// [iOS] if touch is bound to any parent of the iframe blur
-					// happens twice before touchstart and before touchend (#10714).
+					// happens twice before touchstart and before touchend (https://dev.ckeditor.com/ticket/10714).
 					if ( CKEDITOR.env.iOS ) {
 						// Prevent false hiding on blur.
 						// We don't need to return focus here because touchend will fire anyway.
@@ -264,16 +267,16 @@ CKEDITOR.plugins.add( 'floatpanel', {
 						var target = element;
 
 						// Reset panel width as the new content can be narrower
-						// than the old one. (#9355)
+						// than the old one. (https://dev.ckeditor.com/ticket/9355)
 						target.removeStyle( 'width' );
 
 						if ( block.autoSize ) {
-							var panelDoc = block.element.getDocument();
-							var width = ( CKEDITOR.env.webkit ? block.element : panelDoc.getBody() ).$.scrollWidth;
+							var panelDoc = block.element.getDocument(),
+								width = ( ( CKEDITOR.env.webkit || CKEDITOR.env.edge ) ? block.element : panelDoc.getBody() ).$.scrollWidth;
 
 							// Account for extra height needed due to IE quirks box model bug:
 							// http://en.wikipedia.org/wiki/Internet_Explorer_box_model_bug
-							// (#3426)
+							// (https://dev.ckeditor.com/ticket/3426)
 							if ( CKEDITOR.env.ie && CKEDITOR.env.quirks && width > 0 )
 								width += ( target.$.offsetWidth || 0 ) - ( target.$.clientWidth || 0 ) + 3;
 
@@ -286,7 +289,7 @@ CKEDITOR.plugins.add( 'floatpanel', {
 
 							// Account for extra height needed due to IE quirks box model bug:
 							// http://en.wikipedia.org/wiki/Internet_Explorer_box_model_bug
-							// (#3426)
+							// (https://dev.ckeditor.com/ticket/3426)
 							if ( CKEDITOR.env.ie && CKEDITOR.env.quirks && height > 0 )
 								height += ( target.$.offsetHeight || 0 ) - ( target.$.clientHeight || 0 ) + 3;
 
@@ -362,26 +365,28 @@ CKEDITOR.plugins.add( 'floatpanel', {
 
 						// If IE is in RTL, we have troubles with absolute
 						// position and horizontal scrolls. Here we have a
-						// series of hacks to workaround it. (#6146)
-						if ( CKEDITOR.env.ie ) {
-							var offsetParent = new CKEDITOR.dom.element( element.$.offsetParent ),
+						// series of hacks to workaround it. (https://dev.ckeditor.com/ticket/6146)
+						if ( CKEDITOR.env.ie && !CKEDITOR.env.edge ) {
+							var offsetParent = element.$.offsetParent && new CKEDITOR.dom.element( element.$.offsetParent ),
 								scrollParent = offsetParent;
 
 							// Quirks returns <body>, but standards returns <html>.
-							if ( scrollParent.getName() == 'html' )
+							if ( scrollParent && scrollParent.getName() == 'html' ) {
 								scrollParent = scrollParent.getDocument().getBody();
+							}
 
-							if ( scrollParent.getComputedStyle( 'direction' ) == 'rtl' ) {
+							if ( scrollParent && scrollParent.getComputedStyle( 'direction' ) == 'rtl' ) {
 								// For IE8, there is not much logic on this, but it works.
-								if ( CKEDITOR.env.ie8Compat )
+								if ( CKEDITOR.env.ie8Compat ) {
 									left -= element.getDocument().getDocumentElement().$.scrollLeft * 2;
-								else
+								} else {
 									left -= ( offsetParent.$.scrollWidth - offsetParent.$.clientWidth );
+								}
 							}
 						}
 
 						// Trigger the onHide event of the previously active panel to prevent
-						// incorrect styles from being applied (#6170)
+						// incorrect styles from being applied (https://dev.ckeditor.com/ticket/6170)
 						var innerElement = element.getFirst(),
 							activePanel;
 						if ( ( activePanel = innerElement.getCustomData( 'activePanel' ) ) )
@@ -408,12 +413,24 @@ CKEDITOR.plugins.add( 'floatpanel', {
 						// Focus the block now.
 						block.element.focus();
 
-						// #10623, #10951 - restore the viewport's scroll position after focusing list element.
+						// https://dev.ckeditor.com/ticket/10623, https://dev.ckeditor.com/ticket/10951 - restore the viewport's scroll position after focusing list element.
 						if ( CKEDITOR.env.webkit )
 							CKEDITOR.document.getBody().$.scrollTop = scrollTop;
 
 						// We need this get fired manually because of unfired focus() function.
 						this.allowBlur( true );
+
+						// Ensure that the first item is focused (https://dev.ckeditor.com/ticket/16804).
+						if ( this._.markFirst ) {
+							if ( CKEDITOR.env.ie ) {
+								CKEDITOR.tools.setTimeout( function() {
+									block.markFirstDisplayed ? block.markFirstDisplayed() : block._.markFirstDisplayed();
+								}, 0 );
+							} else {
+								block.markFirstDisplayed ? block.markFirstDisplayed() : block._.markFirstDisplayed();
+							}
+						}
+
 						this._.editor.fire( 'panelShow', this );
 					}, 0, this );
 				}, CKEDITOR.env.air ? 200 : 0, this );
@@ -424,7 +441,21 @@ CKEDITOR.plugins.add( 'floatpanel', {
 			},
 
 			/**
-			 * Restores last focused element or simply focus panel window.
+			 * Repositions the panel with the same parameters that were used in the last {@link #showBlock} call.
+			 *
+			 * @since 4.5.4
+			 */
+			reposition: function() {
+				var blockParams = this._.showBlockParams;
+
+				if ( this.visible && this._.showBlockParams ) {
+					this.hide();
+					this.showBlock.apply( this, blockParams );
+				}
+			},
+
+			/**
+			 * Restores the last focused element or simply focuses the panel window.
 			 */
 			focus: function() {
 				// Webkit requires to blur any previous focused page element, in
@@ -450,20 +481,20 @@ CKEDITOR.plugins.add( 'floatpanel', {
 			},
 
 			/**
-			 * Hides panel.
+			 * Hides the panel.
 			 *
 			 * @todo
 			 */
 			hide: function( returnFocus ) {
 				if ( this.visible && ( !this.onHide || this.onHide.call( this ) !== true ) ) {
 					this.hideChild();
-					// Blur previously focused element. (#6671)
+					// Blur previously focused element. (https://dev.ckeditor.com/ticket/6671)
 					CKEDITOR.env.gecko && this._.iframe.getFrameDocument().$.activeElement.blur();
 					this.element.setStyle( 'display', 'none' );
 					this.visible = 0;
 					this.element.getFirst().removeCustomData( 'activePanel' );
 
-					// Return focus properly. (#6247)
+					// Return focus properly. (https://dev.ckeditor.com/ticket/6247)
 					var focusReturn = returnFocus && this._.returnFocus;
 					if ( focusReturn ) {
 						// Webkit requires focus moved out panel iframe first.
@@ -474,6 +505,7 @@ CKEDITOR.plugins.add( 'floatpanel', {
 					}
 
 					delete this._.lastFocused;
+					this._.showBlockParams = null;
 
 					this._.editor.fire( 'panelHide', this );
 				}
@@ -483,7 +515,7 @@ CKEDITOR.plugins.add( 'floatpanel', {
 			 * @todo
 			 */
 			allowBlur: function( allow ) {
-				// Prevent editor from hiding the panel. (#3222)
+				// Prevent editor from hiding the panel. (https://dev.ckeditor.com/ticket/3222)
 				var panel = this._.panel;
 				if ( allow !== undefined )
 					panel.allowBlur = allow;
@@ -492,7 +524,7 @@ CKEDITOR.plugins.add( 'floatpanel', {
 			},
 
 			/**
-			 * Shows specified panel as a child of one block of this one.
+			 * Shows the specified panel as a child of one block of this one.
 			 *
 			 * @param {CKEDITOR.ui.floatPanel} panel
 			 * @param {String} blockName
@@ -536,7 +568,7 @@ CKEDITOR.plugins.add( 'floatpanel', {
 				panel.showBlock( blockName, offsetParent, corner, offsetX, offsetY );
 				this.blur();
 
-				/* #3767 IE: Second level menu may not have borders */
+				/* https://dev.ckeditor.com/ticket/3767 IE: Second level menu may not have borders */
 				if ( CKEDITOR.env.ie7Compat || CKEDITOR.env.ie6Compat ) {
 					setTimeout( function() {
 						panel.element.getChild( 0 ).$.style.cssText += '';
@@ -567,10 +599,10 @@ CKEDITOR.plugins.add( 'floatpanel', {
 
 		for ( var i in panels ) {
 			var panel = panels[ i ];
-			// Safe to destroy it since there're no more instances.(#4241)
+			// Safe to destroy it since there're no more instances.(https://dev.ckeditor.com/ticket/4241)
 			if ( isLastInstance )
 				panel.destroy();
-			// Panel might be used by other instances, just hide them.(#4552)
+			// Panel might be used by other instances, just hide them.(https://dev.ckeditor.com/ticket/4552)
 			else
 				panel.element.hide();
 		}
