@@ -1,10 +1,10 @@
-﻿/*
-Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
-For licensing, see LICENSE.md or http://ckeditor.com/license
+/*
+Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
+For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */
 CKEDITOR.plugins.setLang( 'format', 'sl', {
 	label: 'Oblika',
-	panelTitle: 'Oblika',
+	panelTitle: 'Oblika odstavka',
 	tag_address: 'Napis',
 	tag_div: 'Navaden (DIV)',
 	tag_h1: 'Naslov 1',
