@@ -1,9 +1,9 @@
-﻿/*
-Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
-For licensing, see LICENSE.md or http://ckeditor.com/license
+/*
+Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
+For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */
 CKEDITOR.plugins.setLang( 'stylescombo', 'bn', {
-	label: 'স্টাইল',
+	label: 'ধরন',
 	panelTitle: 'Formatting Styles', // MISSING
 	panelTitle1: 'Block Styles', // MISSING
 	panelTitle2: 'Inline Styles', // MISSING
