@@ -1,6 +1,6 @@
-﻿/**
- * @license Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
- * For licensing, see LICENSE.md or http://ckeditor.com/license
+/**
+ * @license Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
+ * For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
  */
 
 ( function() {
@@ -34,7 +34,7 @@
 	function validatorNum( msg ) {
 		return function() {
 			var value = this.getValue(),
-				pass = !!( CKEDITOR.dialog.validate.integer()( value ) && value > 0 );
+				pass = !!( CKEDITOR.dialog.validate.integer().call( this, value ) && value > 0 );
 
 			if ( !pass ) {
 				alert( msg ); // jshint ignore:line
@@ -59,6 +59,17 @@
 			minWidth: 310,
 			minHeight: CKEDITOR.env.ie ? 310 : 280,
 
+			getModel: function( editor ) {
+				if ( this.dialog.getName() !== 'tableProperties' ) {
+					return null;
+				}
+
+				var selection = editor.getSelection(),
+					range = selection && selection.getRanges()[ 0 ];
+
+				return range ? range._getTableElement( { table: 1 } ) : null;
+			},
+
 			onLoad: function() {
 				var dialog = this;
 
@@ -97,7 +108,7 @@
 					if ( selected && selected.is( 'table' ) )
 						table = selected;
 					else if ( ranges.length > 0 ) {
-						// Webkit could report the following range on cell selection (#4948):
+						// Webkit could report the following range on cell selection (https://dev.ckeditor.com/ticket/4948):
 						// <table><tr><td>[&nbsp;</td></tr></table>]
 						if ( CKEDITOR.env.webkit )
 							ranges[ 0 ].shrink( CKEDITOR.NODE_ELEMENT );
@@ -157,14 +168,19 @@
 					// Should we make a <thead>?
 					var headers = info.selHeaders;
 					if ( !table.$.tHead && ( headers == 'row' || headers == 'both' ) ) {
-						var thead = new CKEDITOR.dom.element( table.$.createTHead() );
+						var thead = table.getElementsByTag( 'thead' ).getItem( 0 );
 						tbody = table.getElementsByTag( 'tbody' ).getItem( 0 );
 						var theRow = tbody.getElementsByTag( 'tr' ).getItem( 0 );
 
+						if ( !thead ) {
+							thead = new CKEDITOR.dom.element( 'thead' );
+							thead.insertBefore( tbody );
+						}
+
 						// Change TD to TH:
 						for ( i = 0; i < theRow.getChildCount(); i++ ) {
 							var th = theRow.getChild( i );
-							// Skip bookmark nodes. (#6155)
+							// Skip bookmark nodes. (https://dev.ckeditor.com/ticket/6155)
 							if ( th.type == CKEDITOR.NODE_ELEMENT && !th.data( 'cke-bookmark' ) ) {
 								th.renameNode( 'th' );
 								th.setAttribute( 'scope', 'col' );
@@ -178,7 +194,6 @@
 						thead = new CKEDITOR.dom.element( table.$.tHead );
 						tbody = table.getElementsByTag( 'tbody' ).getItem( 0 );
 
-						var previousFirstRow = tbody.getFirst();
 						while ( thead.getChildCount() > 0 ) {
 							theRow = thead.getFirst();
 							for ( i = 0; i < theRow.getChildCount(); i++ ) {
@@ -188,7 +203,9 @@
 									newCell.removeAttribute( 'scope' );
 								}
 							}
-							theRow.insertBefore( previousFirstRow );
+
+							// Append the row to the start (#1397).
+							tbody.append( theRow, true );
 						}
 						thead.remove();
 					}
@@ -226,7 +243,7 @@
 				if ( !this._.selectedElement ) {
 					editor.insertElement( table );
 					// Override the default cursor position after insertElement to place
-					// cursor inside the first cell (#7959), IE needs a while.
+					// cursor inside the first cell (https://dev.ckeditor.com/ticket/7959), IE needs a while.
 					setTimeout( function() {
 						var firstCell = new CKEDITOR.dom.element( table.$.rows[ 0 ].cells[ 0 ] );
 						var range = editor.createRange();
@@ -234,7 +251,7 @@
 						range.select();
 					}, 0 );
 				}
-				// Properly restore the selection, (#4822) but don't break
+				// Properly restore the selection, (https://dev.ckeditor.com/ticket/4822) but don't break
 				// because of this, e.g. updated table caption.
 				else {
 					try {
@@ -345,9 +362,9 @@
 							label: editor.lang.common.align,
 							items: [
 								[ editor.lang.common.notSet, '' ],
-								[ editor.lang.common.alignLeft, 'left' ],
-								[ editor.lang.common.alignCenter, 'center' ],
-								[ editor.lang.common.alignRight, 'right' ]
+								[ editor.lang.common.left, 'left' ],
+								[ editor.lang.common.center, 'center' ],
+								[ editor.lang.common.right, 'right' ]
 							],
 							setup: function( selectedTable ) {
 								this.setValue( selectedTable.getAttribute( 'align' ) || '' );
@@ -373,7 +390,7 @@
 								controlStyle: 'width:5em',
 								label: editor.lang.common.width,
 								title: editor.lang.common.cssLengthTooltip,
-								// Smarter default table width. (#9600)
+								// Smarter default table width. (https://dev.ckeditor.com/ticket/9600)
 								'default': editor.filter.check( 'table{width}' ) ? ( editable.getSize( 'width' ) < 500 ? '100%' : 500 ) : 0,
 								getValue: defaultToPixel,
 								validate: CKEDITOR.dialog.validate.cssLength( editor.lang.common.invalidCssLength.replace( '%1', editor.lang.common.width ) ),
@@ -498,10 +515,7 @@
 									captionElement.setHtml( '' );
 								} else {
 									captionElement = new CKEDITOR.dom.element( 'caption', editor.document );
-									if ( table.getChildCount() )
-										captionElement.insertBefore( table.getFirst() );
-									else
-										captionElement.appendTo( table );
+									table.append( captionElement, true );
 								}
 								captionElement.append( new CKEDITOR.dom.text( caption, editor.document ) );
 							} else if ( captionElement.count() > 0 ) {
