@@ -1,6 +1,6 @@
-﻿/*
-Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
-For licensing, see LICENSE.md or http://ckeditor.com/license
+/*
+Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
+For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */
 CKEDITOR.plugins.setLang( 'toolbar', 'bg', {
 	toolbarCollapse: 'Свиване на лентата с инструменти',
@@ -8,7 +8,7 @@ CKEDITOR.plugins.setLang( 'toolbar', 'bg', {
 	toolbarGroups: {
 		document: 'Документ',
 		clipboard: 'Клипборд/Отмяна',
-		editing: 'Промяна',
+		editing: 'Редакция',
 		forms: 'Форми',
 		basicstyles: 'Базови стилове',
 		paragraph: 'Параграф',
