@@ -1,6 +1,6 @@
-﻿/*
-Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
-For licensing, see LICENSE.md or http://ckeditor.com/license
+/*
+Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
+For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */
 CKEDITOR.plugins.setLang( 'toolbar', 'sk', {
 	toolbarCollapse: 'Zbaliť lištu nástrojov',
@@ -11,7 +11,7 @@ CKEDITOR.plugins.setLang( 'toolbar', 'sk', {
 		editing: 'Upravovanie',
 		forms: 'Formuláre',
 		basicstyles: 'Základné štýly',
-		paragraph: 'Odstavec',
+		paragraph: 'Odsek',
 		links: 'Odkazy',
 		insert: 'Vložiť',
 		styles: 'Štýly',
